"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIReferenceModel = void 0;
const semantics_entities_semantic_schema_1 = require("@teambit/semantics.entities.semantic-schema");
const component_id_1 = require("@teambit/component-id");
class APIReferenceModel {
    constructor(_api, _renderers) {
        this.componentId = _api.componentId;
        this.apiNodes = this.mapToAPINode(_api, _renderers, this.componentId);
        this.apiByType = this.groupByType(this.apiNodes);
        this.apiByName = this.groupByName(this.apiNodes);
    }
    mapToAPINode(api, renderers, componentId) {
        const { exports: schemaNodes } = api.module;
        const defaultRenderers = renderers.filter((renderer) => renderer.default);
        const nonDefaultRenderers = renderers.filter((renderer) => !renderer.default);
        return schemaNodes
            .map((schemaNode) => ({
            componentId,
            api: schemaNode,
            renderer: nonDefaultRenderers.find((renderer) => renderer.predicate(schemaNode)) ||
                defaultRenderers.find((renderer) => renderer.predicate(schemaNode)),
        }))
            .filter((schemaNode) => schemaNode.renderer);
    }
    getByType(type) {
        return this.apiByType.get(type);
    }
    groupByType(apiNodes) {
        return apiNodes.reduce((accum, next) => {
            const existing = accum.get(next.renderer.nodeType) || [];
            accum.set(next.renderer.nodeType, existing.concat(next));
            return accum;
        }, new Map());
    }
    groupByName(apiNodes) {
        return apiNodes.reduce((accum, next) => {
            if (!next.api.name)
                return accum;
            accum.set(next.api.name, next);
            return accum;
        }, new Map());
    }
    static from(result, renderers) {
        try {
            const apiSchema = semantics_entities_semantic_schema_1.APISchema.fromObject(result.getHost.getSchema);
            return new APIReferenceModel(apiSchema, renderers);
        }
        catch (e) {
            return new APIReferenceModel(semantics_entities_semantic_schema_1.APISchema.empty(component_id_1.ComponentID.fromObject(result.getHost.getSchema.componentId)), renderers);
        }
    }
}
exports.APIReferenceModel = APIReferenceModel;
//# sourceMappingURL=api-reference-model.js.map